@@ -1,7 +1,18 @@
-#!/bin/perl
-
-#my %Lang;
-#use strict;
+#!/usr/bin/perl
+#
+#   This program is free software: you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation, either version 3 of the License, or
+#   (at your option) any later version.
+#
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License
+#   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
 
 # --------------------------------
 
@@ -40,18 +51,22 @@ $Lang{Admin_Options_Page} = <<EOF;
 </ul>
 -->
 EOF
-$Lang{Unable_to_connect_to_BackupPC_server} = "Impossible de se connecter au serveur BackupPC",
-            "Ce script CGI (\$MyURL) est incapable de se connecter au serveur BackupPC"
-          . " sur \$Conf{ServerHost} au port \$Conf{ServerPort}. L'erreur"
-          . " est: \$err."
-          . " Il est possible que le serveur BackupPC ne fonctionne pas actuellement ou qu'il"
-          . " y ait une erreur de configuration. Veuillez contacter votre administrateur systme.";
+
+$Lang{Unable_to_connect_to_BackupPC_server} = "Impossible de se connecter au serveur BackupPC";
+$Lang{Unable_to_connect_to_BackupPC_server_error_message} = <<EOF;
+Ce script CGI (\$MyURL) est incapable de se connecter au serveur BackupPC
+sur \$Conf{ServerHost} au port \$Conf{ServerPort}.<br>
+L'erreur est: \$err.<br>
+Il est possible que le serveur BackupPC ne fonctionne pas actuellement ou qu'il
+y ait une erreur de configuration. Veuillez contacter votre administrateur systme.
+EOF
+
 $Lang{Admin_Start_Server} = <<EOF;
 \${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
 <form action="\$MyURL" method="get">
 Le serveur BackupPC sur <tt>\$Conf{ServerHost}</tt>, port <tt>\$Conf{ServerPort}</tt>
 n'est pas en fonction (vous l'avez peut-tre arrt, ou vous ne l'avez pas encore dmarr).<br>
-Voulez-vous le dmarrer?
+Voulez-vous le dmarrer ?
 <input type="hidden" name="action" value="startServer">
 <input type="submit" value="Dmarrer le serveur" name="ignore">
 </form>
@@ -67,7 +82,7 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
 <ul>
 <li> Le PID du serveur est \$Info{pid}, sur l\'hte \$Conf{ServerHost},
      version \$Info{Version}, dmarr le \$serverStartTime.
-<li> Ce rapport  t gnr le \$now.
+<li> Ce rapport a t gnr le \$now.
 <li> La configuration a t charge pour la dernire fois  \$configLoadTime.
 <li> La prochaine file d\'attente sera remplie  \$nextWakeupTime.
 <li> Autres infos:
@@ -78,7 +93,10 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
         \$poolInfo
         <li>L\'espace de stockage a t rcemment rempli  \$Info{DUlastValue}%
             (\$DUlastTime), le maximum aujourd\'hui a t de \$Info{DUDailyMax}% (\$DUmaxTime)
-            et hier le maximum tait \$Info{DUDailyMaxPrev}%.
+            et hier le maximum tait de \$Info{DUDailyMaxPrev}%.
+        <li>Inode L\'espace de stockage a t rcemment rempli  \$Info{DUInodelastValue}%
+            (\$DUlastTime), le maximum aujourd\'hui a t de \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+            et hier le maximum tait de \$Info{DUInodeDailyMaxPrev}%.
     </ul>
 </ul>
 EOF
@@ -87,11 +105,9 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 \${h1(qq{$Lang{H_BackupPC_Server_Status}})}
 
 <p>
-\$generalInfo
-
 \${h2("Travaux en cours d'excution")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td> Hte </td>
     <td> Type </td>
     <td> Utilisateur </td>
@@ -99,14 +115,18 @@ $Lang{BackupPC_Server_Status} = <<EOF;
     <td> Commande </td>
     <td align="center"> PID </td>
     <td align="center"> PID du transfert </td>
+    <td align="center"> Status </td>
+    <td align="center"> Count </td>
     </tr>
 \$jobStr
 </table>
+
 <p>
+\$generalInfo
 
 \${h2("checs qui demandent de l'attention")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Hte </td>
     <td align="center"> Type </td>
     <td align="center"> Utilisateur </td>
@@ -127,9 +147,12 @@ $Lang{BackupPC_Summary}=<<EOF;
 <p>
 <ul>
 <li>Ce statut a t gnr le \$now.
-<li>L\'espace de stockage a ?t? r?cemment rempli ? \$Info{DUlastValue}%
-    (\$DUlastTime), le maximum aujourd\'hui a ?t? de \$Info{DUDailyMax}% (\$DUmaxTime)
-    et hier le maximum ?tait \$Info{DUDailyMaxPrev}%.
+<li>L\'espace de stockage a t rcemment rempli  \$Info{DUlastValue}%
+    (\$DUlastTime), le maximum aujourd\'hui a t de \$Info{DUDailyMax}% (\$DUmaxTime)
+    et hier le maximum tait de \$Info{DUDailyMaxPrev}%.
+<li>Inode L\'espace de stockage a t rcemment rempli  \$Info{DUInodelastValue}%
+    (\$DUlastTime), le maximum aujourd\'hui a t de \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+    et hier le maximum tait de \$Info{DUInodeDailyMaxPrev}%.
 </ul>
 </p>
 
@@ -146,6 +169,7 @@ Il y a \$hostCntGood htes ayant t sauvegards, pour un total de :
 <table class="sortable" id="host_summary_backups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Hte </td>
     <td align="center"> Utilisateur </td>
+    <td align="center"> Commentaire </td>
     <td align="center"> Nb compltes </td>
     <td align="center"> Compltes ge (jours) </td>
     <td align="center"> Compltes Taille (Go) </td>
@@ -154,10 +178,10 @@ Il y a \$hostCntGood htes ayant t sauvegards, pour un total de :
     <td align="center"> Incrmentielles ge (jours) </td>
     <td align="center"> Dernire sauvegarde (jours) </td>
     <td align="center"> tat actuel </td>
+    <td align="center"> Nb erreurs transfert </td>
     <td align="center"> Dernire tentative </td></tr>
 \$strGood
 </table>
-<br><br>
 \${h2("Htes sans sauvegardes")}
 <p>
 Il y a \$hostCntNone htes sans sauvegardes.
@@ -165,6 +189,7 @@ Il y a \$hostCntNone htes sans sauvegardes.
 <table class="sortable" id="host_summary_nobackups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Hte </td>
     <td align="center"> Utilisateur </td>
+    <td align="center"> Commentaire </td>
     <td align="center"> Nb compltes </td>
     <td align="center"> Compltes ge (jours) </td>
     <td align="center"> Compltes Taille (Go) </td>
@@ -173,6 +198,7 @@ Il y a \$hostCntNone htes sans sauvegardes.
     <td align="center"> Incrmentielles ge (jours) </td>
     <td align="center"> Dernire sauvegarde (jours) </td>
     <td align="center"> tat actuel </td>
+    <td align="center"> Nb erreurs transfert </td>
     <td align="center"> Dernire tentative </td></tr>
 \$strNone
 </table>
@@ -291,6 +317,7 @@ EOF
 
 # -----------------------------------
 $Lang{BackupPC__Backup_Requested_on__host} = "BackupPC: Sauvegarde demande sur \$host";
+$Lang{BackupPC__Delete_Requested_for_a_backup_of__host} = "BackupPC: Delete Requested for a backup of \$host";
 # --------------------------------
 $Lang{REPLY_FROM_SERVER} = <<EOF;
 \${h1(\$str)}
@@ -303,7 +330,7 @@ EOF
 $Lang{BackupPC__Start_Backup_Confirm_on__host} = "BackupPC: Confirmation du dmarrage de la sauvegarde de \$host";
 # --------------------------------
 $Lang{Are_you_sure_start} = <<EOF;
-\${h1("tes vous certain ?")}
+\${h1("tes-vous certain ?")}
 <p>
 Vous allez bientt dmarrer une sauvegarde \$type depuis \$host.
 
@@ -324,7 +351,7 @@ $Lang{BackupPC__Stop_Backup_Confirm_on__host} = "BackupPC: Confirmer l\'arrt de
 # --------------------------------
 $Lang{Are_you_sure_stop} = <<EOF;
 
-\${h1("tes vous certain ?")}
+\${h1("tes-vous certain ?")}
 
 <p>
 Vous tes sur le point d\'arrter/supprimer de la file les sauvegardes de \$host;
@@ -353,36 +380,36 @@ $Lang{BackupPC__Queue_Summary} = "BackupPC: Rsum de la file";
 # --------------------------------
 $Lang{Backup_Queue_Summary} = <<EOF;
 \${h1("Rsum de la file")}
-<br><br>
 \${h2("Rsum des files des utilisateurs")}
 <p>
 Les demandes utilisateurs suivantes sont actuellement en attente :
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Hte </td>
+    <td> Action </td>
     <td> Temps Requis </td>
     <td> Utilisateur </td></tr>
 \$strUser
 </table>
-<br><br>
 
 \${h2("Rsum de la file en arrire plan")}
 <p>
 Les demandes en arrire plan suivantes sont actuellement en attente :
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Hte </td>
+    <td> Action </td>
     <td> Temps requis </td>
     <td> Utilisateur </td></tr>
 \$strBg
 </table>
-<br><br>
 \${h2("Rsum de la file d\'attente des commandes")}
 <p>
 Les demandes de commande suivantes sont actuellement en attente :
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Htes </td>
+    <td> Action </td>
     <td> Temps Requis </td>
     <td> Utilisateur </td>
     <td> Commande </td></tr>
@@ -411,7 +438,7 @@ $Lang{BackupPC__Log_File_History} = "BackupPC: Historique du fichier journal";
 $Lang{Log_File_History__hdr} = <<EOF;
 \${h1("Historique du fichier journal \$hdr")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Fichier </td>
     <td align="center"> Taille </td>
     <td align="center"> Date de modification </td></tr>
@@ -423,7 +450,7 @@ EOF
 $Lang{Recent_Email_Summary} = <<EOF;
 \${h1("Rsum des courriels rcents (du plus rcent au plus vieux)")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Destinataire </td>
     <td align="center"> Hte </td>
     <td align="center"> Date </td>
@@ -522,8 +549,15 @@ et transfrer cette archive, et vous aurez besoin d\'assez d\'espace disque pour
 \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (Autrement l\'archive contiendra les chemins complets).
 <br>
-Compression (0=dsactive, 1=rapide,...,9=meilleure)
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>Compression (0=dsactive, 1=rapide,...,9=meilleure)</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="Tlcharger le fichier Zip" name="ignore">
 </form>
@@ -576,7 +610,7 @@ EOF
 $Lang{Restore_Confirm_on__host} = "BackupPC: Confirmation de restauration sur \$host";
 
 $Lang{Are_you_sure} = <<EOF;
-\${h1("tes-vous sur ?")}
+\${h1("tes-vous sr ?")}
 <p>
 Vous tes sur le point de dmarrer une restauration directement sur 
 la machine \$In{hostDest}. Les fichiers suivants vont tre restaurs 
@@ -621,6 +655,34 @@ La rponse du serveur est : \$reply
 EOF
 
 
+# --------------------------------
+$Lang{BackupPC__Delete_Backup_Confirm__num_of__host} = "BackupPC: Delete Backup Confirm #\$num of \$host";
+# --------------------------------
+$Lang{A_filled} = "a filled";
+$Lang{An_unfilled} = "an unfilled";
+$Lang{Are_you_sure_delete} = <<EOF;
+\${h1("Are you sure?")}
+<p>
+You are about to delete \$filled \$type backup #\$num of \$host.
+
+<form name="Confirm" action="\$MyURL" method="get">
+
+<input type="hidden" name="host" value="\${EscHTML(\$host)}">
+<input type="hidden" name="num" value="\$num">
+
+<input type="hidden" name="doit" value="1">
+<input type="hidden" name="action" value="">
+
+Do you really want to do this?
+
+<input type="button" value="\${EscHTML(\$Lang->{CfgEdit_Button_Delete})}"
+ onClick="document.Confirm.action.value='deleteBackup';
+          document.Confirm.submit();">
+
+<input type="submit" value="No" name="ignore">
+</form>
+EOF
+
 # -------------------------
 $Lang{Host__host_Backup_Summary} = "BackupPC: Rsum de la sauvegarde de l\'hte \$host ";
 
@@ -650,7 +712,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 <p>
 Cliquer sur le numro de l\'archive pour naviguer et restaurer les fichiers de sauvegarde.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Sauvegarde n </td>
     <td align="center"> Type </td>
     <td align="center"> Fusionne </td> 
@@ -658,6 +720,7 @@ Cliquer sur le numro de l\'archive pour naviguer et restaurer les fichiers de sa
     <td align="center"> Date de dmarrage </td>
     <td align="center"> Dure (min) </td>
     <td align="center"> ge (jours) </td>
+    \$deleteHdrStr
     <td align="center"> Chemin d\'accs de la sauvegarde sur le serveur </td>
 </tr>
 \$str
@@ -666,10 +729,8 @@ Cliquer sur le numro de l\'archive pour naviguer et restaurer les fichiers de sa
 
 \$restoreStr
 </p>
-<br><br>
 \${h2("Rsum des erreurs de transfert")}
-<br><br>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Sauvegarde n </td>
     <td align="center"> Type </td>
     <td align="center"> Voir </td>
@@ -680,21 +741,20 @@ Cliquer sur le numro de l\'archive pour naviguer et restaurer les fichiers de sa
 </tr>
 \$errStr
 </table>
-<br><br>
 
-\${h2("Rcapitulatif de la taille des fichier et du nombre de rutilisations")}
+\${h2("Rcapitulatif de la taille des fichiers et du nombre de rutilisations")}
 <p>
 Les fichiers existants sont ceux qui sont dj sur le serveur; 
 Les nouveaux fichiers sont ceux qui ont t ajouts au serveur.
 Les fichiers vides et les erreurs de SMB ne sont pas comptabiliss dans les fichiers nouveaux ou rutiliss.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="2" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Totaux </td>
     <td align="center" colspan="2"> Fichiers existants </td>
     <td align="center" colspan="2"> Nouveaux fichiers </td>
 </tr>
-<tr class="tableheader">
+<tr class="tableheader sortheader">
     <td align="center"> Sauvegarde n </td>
     <td align="center"> Type </td>
     <td align="center"> Nb de Fichiers </td>
@@ -707,19 +767,18 @@ Les fichiers vides et les erreurs de SMB ne sont pas comptabiliss dans les fichi
 </tr>
 \$sizeStr
 </table>
-<br><br>
 
 \${h2("Rsum de la compression")}
 <p>
 Performance de la compression pour les fichiers dj sur le serveur et
 rcemment compresss.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="3" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Fichiers existants </td>
     <td align="center" colspan="3"> Nouveaux fichiers </td>
 </tr>
-<tr class="tableheader"><td align="center"> Nb de sauvegardes </td>
+<tr class="tableheader sortheader"><td align="center"> Nb de sauvegardes </td>
     <td align="center"> Type </td>
     <td align="center"> Niveau de Compression </td>
     <td align="center"> Taille (Mo) </td>
@@ -731,7 +790,6 @@ rcemment compresss.
 </tr>
 \$compStr
 </table>
-<br><br>
 EOF
 
 $Lang{Host__host_Archive_Summary} = "BackupPC: Rsum de l'archivage pour l'hte \$host";
@@ -819,7 +877,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("Contenu de \${EscHTML(\$dirDisplay)}")}
+\${h2("Contenu de \$dirDisplay")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -871,14 +929,14 @@ Cette page montre toutes les version disponibles des fichiers sauvegards pour le
 <li> Cliquez sur une version d'un fichier (\$Lang->{DirHistory_fileLink}0,
      \$Lang->{DirHistory_fileLink}1, ...) pour le tlcharger.
 <li> Les fichiers avec des contenus identiques pour plusieurs sauvegardes ont 
-     le mme numro de version.
+     le mme numro de version, sauf entre des sauvegardes en v3 et v4.
 <li> Les fichiers qui ne sont pas prsents sur une sauvegarde en particulier 
      sont reprsents par une bote vide.
 <li> Les fichiers montrs avec la mme version peuvent avoir des attributs diffrents. 
      Choisissez le numro de sauvegarde pour voir les attributs de fichiers.
 </ul>
 
-\${h2("Historique de \${EscHTML(\$dirDisplay)}")}
+\${h2("Historique de \$dirDisplay")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -968,13 +1026,15 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
                   "Seuls les utilisateurs privilgis peuvent arrter ou dmarrer des sauvegardes sur "
                   . " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "Numro invalide \$num";
+$Lang{Invalid_number__num} = "Numro invalide \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "Impossible d\'ouvrir \$file : problme de configuration ?";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Seuls les utilisateurs privilgis peuvent voir les fichiers de journal ou les fichiers de configuration.";
 $Lang{Only_privileged_users_can_view_log_files} = "Seuls les utilisateurs privilgis peuvent voir les fichiers de journal.";
 $Lang{Only_privileged_users_can_view_email_summaries} = "Seuls les utilisateurs privilgis peuvent voir les compte-rendus des courriels.";
 $Lang{Only_privileged_users_can_browse_backup_files} = "Seuls les utilisateurs privilgis peuvent parcourir les fichiers de sauvegarde"
                  . " pour l'hte \${EscHTML(\$In{host})}.";
+$Lang{Only_privileged_users_can_delete_backups} = "Only privileged users can delete backups"
+                . " of host \${EscHTML(\$host)}.";
 $Lang{Empty_host_name} = "Nom d\'hte vide.";
 $Lang{Directory___EscHTML} = "Le rpertoire \${EscHTML(\"\$TopDir/pc/\$host/\$num\")}"
 		    . " est vide";
@@ -1025,6 +1085,8 @@ $Lang{Backup_requested_on__host_by__User} = "Sauvegarde demande sur \$host par \
 $Lang{Backup_stopped_dequeued_on__host_by__User} = "Sauvegarde arrte/dprogramme pour \$host par \$User";
 $Lang{Restore_requested_to_host__hostDest__backup___num} = "Restauration demande pour l\'hte \$hostDest, "
              . "sauvegarde n\$num, par \$User depuis \$ENV{REMOTE_ADDR}";
+$Lang{Delete_requested_for_backup_of__host_by__User} = "Delete requested for backup #\$num of \$host"
+             . " by \$User from \$ENV{REMOTE_ADDR}";
 $Lang{Archive_requested} = "Archivage demand par \$User de \$ENV{REMOTE_ADDR}";
 
 # -------------------------------------------------
@@ -1162,7 +1224,7 @@ $Lang{Restore_Summary} = <<EOF;
 \${h2("Rsum de la restauration")}
 <p>
 Cliquer sur le numro de restauration pour plus de dtails.
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Sauvegarde n </td>
     <td align="center"> Rsultat </td>
     <td align="right"> Date de dpart</td>
@@ -1198,7 +1260,7 @@ $Lang{No} = "non";
 $Lang{Yes} = "oui";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">Le rpertoire \${EscHTML(\$dirDisplay)} est vide
+<tr><td bgcolor="#ffffff">Le rpertoire \$dirDisplay est vide
 </td></tr>
 EOF
 
@@ -1207,6 +1269,7 @@ $Lang{off} = "inactif";
 
 $Lang{backupType_full}    = "complte";
 $Lang{backupType_incr}    = "incrmentielle";
+$Lang{backupType_active}  = "active";
 $Lang{backupType_partial} = "partielle";
 
 $Lang{failed} = "chec";
@@ -1220,8 +1283,8 @@ $Lang{Status_backup_starting} = "dbut de la sauvegarde";
 $Lang{Status_backup_in_progress} = "sauvegarde en cours";
 $Lang{Status_restore_starting} = "dbut de la restauration";
 $Lang{Status_restore_in_progress} = "restauration en cours";
-$Lang{Status_link_pending} = "en attente de l'dition de liens";
-$Lang{Status_link_running} = "dition de liens en cours";
+$Lang{Status_admin_pending} = "en attente de l'dition de liens";
+$Lang{Status_admin_running} = "dition de liens en cours";
 
 $Lang{Reason_backup_done}    = "sauvegarde termine";
 $Lang{Reason_restore_done}   = "restauration termine";
@@ -1267,7 +1330,7 @@ ordinateur est correctement connect au rseau.
 
 Merci de votre attention,
 BackupPC Gnie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # No recent backup
@@ -1298,7 +1361,7 @@ avec votre ordinateur.
 
 Merci de votre attention,
 BackupPC Gnie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # Old Outlook files
@@ -1330,7 +1393,7 @@ sauvegarde devrait prendre quelques minutes  s'effectuer.
 
 Merci de votre attention,
 BackupPC Gnie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 $Lang{howLong_not_been_backed_up} = "jamais t sauvegards";
@@ -1349,6 +1412,7 @@ Vitesse (Mo/s) : \$fullRate;
 Nb incrmentielles : \$incrCnt;
 Incrmentielles ge (jours) : \$incrAge;
 tat actuel : \$host_state;
+Dsactive: \$host_disabled;
 Dernire tentative : \$host_last_attempt;
 EOF
 
@@ -1380,11 +1444,11 @@ $Lang{CfgEdit_Title_User_URLs} = "URL des usagers";
 $Lang{CfgEdit_Title_User_Config_Editing} = "Modifications des configurations des usagers";
 $Lang{CfgEdit_Title_Xfer} = "Xfer";
 $Lang{CfgEdit_Title_Xfer_Settings} = "Paramtres des transfers";
+$Lang{CfgEdit_Title_Ftp_Settings} = "Paramtres de FTP";
 $Lang{CfgEdit_Title_Smb_Settings} = "Paramtres de Smb";
 $Lang{CfgEdit_Title_Tar_Settings} = "Paramtres de Tar";
 $Lang{CfgEdit_Title_Rsync_Settings} = "Paramtres de Rsync";
 $Lang{CfgEdit_Title_Rsyncd_Settings} = "Paramtres de Rsyncd";
-$Lang{CfgEdit_Title_BackupPCd_Settings} = "Paramtres de BackupPCd";
 $Lang{CfgEdit_Title_Archive_Settings} = "Paramtres d'archivage";
 $Lang{CfgEdit_Title_Include_Exclude} = "Inclure/Exclure";
 $Lang{CfgEdit_Title_Smb_Paths_Commands} = "Chemins/Commandes Smb";
@@ -1399,7 +1463,6 @@ $Lang{CfgEdit_Title_Blackouts} = "Suspension";
 $Lang{CfgEdit_Title_Other} = "Divers";
 $Lang{CfgEdit_Title_Backup_Settings} = "Paramtres de sauvegarde";
 $Lang{CfgEdit_Title_Client_Lookup} = "Consultation des clients";
-$Lang{CfgEdit_Title_Other} = "Autre";
 $Lang{CfgEdit_Title_User_Commands} = "Commandes des usagers";
 $Lang{CfgEdit_Title_Hosts} = "Machines";
 
@@ -1433,6 +1496,7 @@ $Lang{CfgEdit_Button_Delete}   = "Dtruire";
 $Lang{CfgEdit_Button_Add}      = "Ajouter";
 $Lang{CfgEdit_Button_Override} = "craser";
 $Lang{CfgEdit_Button_New_Key}  = "Nouvelle cl";
+$Lang{CfgEdit_Button_New_Share} = "New ShareName or '*'";
 
 $Lang{CfgEdit_Error_No_Save}
             = "Erreur: Pas de sauvegarde  cause d'erreurs.";
